@@ -38,21 +38,32 @@ elif str(WOX_DIR_NAME) in CURRENT_WORKING_DIR.parts:
 
 if str(APPDATA.joinpath(launcher_dir)) in str(CURRENT_WORKING_DIR):
     USER_DIR = APPDATA.joinpath(launcher_dir)
-    APP_DIR = LOCALAPPDATA.joinpath(launcher_dir)
+    LOCAL_APP_DIR = LOCALAPPDATA.joinpath(launcher_dir)
 elif "UserData" in CURRENT_WORKING_DIR.parts:
     USER_DIR = CURRENT_WORKING_DIR.parts[:-2]
-    APP_DIR = CURRENT_WORKING_DIR.parts[:-3]
+    LOCAL_APP_DIR = CURRENT_WORKING_DIR.parts[:-3]
 elif APPDATA.joinpath(FLOW_LAUNCHER_DIR_NAME).exits():
     USER_DIR = APPDATA.joinpath(FLOW_LAUNCHER_DIR_NAME)
-    APP_DIR = LOCALAPPDATA.joinpath(FLOW_LAUNCHER_DIR_NAME)
+    LOCAL_APP_DIR = LOCALAPPDATA.joinpath(FLOW_LAUNCHER_DIR_NAME)
     API = FLOW_API
 elif APPDATA.joinpath(WOX_DIR_NAME).exits():
     USER_DIR = APPDATA.joinpath(WOX_DIR_NAME)
-    APP_DIR = LOCALAPPDATA.joinpath(WOX_DIR_NAME)
+    LOCAL_APP_DIR = LOCALAPPDATA.joinpath(WOX_DIR_NAME)
     API = WOX_API
 else:
     raise FileNotFoundError("Unable to locate Launcher directory")
     
+app_versions = LOCAL_APP_DIR.iterdir()
+_versions = []
+for dir in app_versions:
+    dir = str(dir)
+    if "app-" in dir:
+        _version = dir.split("app-")[1]
+        _version = tuple(map(int, (_version.split("."))))
+        _versions.append(_version)
+_version = ".".join(map(str, max(_versions)))
+_dir = f"app-{_version}"
+APP_DIR = LOCALAPPDATA.joinpath(launcher_dir, _dir )
 
 APP_ICONS = os.path.join(APP_DIR, "Images")
 ICON_APP = os.path.join(APP_ICONS, 'app.png')
@@ -137,7 +148,7 @@ class Flox(Launcher):
         )
 
     def issue_item(self, e):
-        trace = ''.join(traceback.format_exception(etype=type(e), value=e, tb=e.__traceback__)).replace('\n', '%0A')
+        trace = ''.join(traceback.format_exception(type(e), value=e, tb=e.__traceback__)).replace('\n', '%0A')
         self.add_item(
             title=self.issue_item_title,
             subtitle=self.issue_item_subtitle,
